@@ -27,6 +27,10 @@ __PACKAGE__->add_columns(
   { data_type => "integer", is_nullable => 0 },
   "node_active_count",
   { data_type => "integer", is_nullable => 0 },
+  "phone_count",
+  { data_type => "integer", is_nullable => 0 },
+  "wap_count",
+  { data_type => "integer", is_nullable => 0 },
   "netdisco_ver",
   { data_type => "text", is_nullable => 1 },
   "snmpinfo_ver",
