@@ -15,7 +15,7 @@ register_device_tab({ tag => 'vlans', label => 'VLANs', provides_csv => 1 });
 get '/ajax/content/device/vlans' => require_login sub {
     my $q = param('q');
 
-    my $device = schema('netdisco')->resultset('Device')
+    my $device = schema(vars->{'tenant'})->resultset('Device')
       ->search_for_device($q) or send_error('Bad device', 400);
     my @results = $device->vlans->search(
       { vlan => { '>' => 0 } }, { order_by => 'vlan' } )->hri->all;
