@@ -97,7 +97,6 @@ $(document).ready(function() {
   // toggle visibility of port up/down and edit controls
   $('.tab-content').on('mouseenter', '.nd_editable-cell', function() {
     $(this).children('.nd_hand-icon').show();
-    $(this).children('.nd_log-icon').css('visibility', 'visible');
     if (! $(this).is(':focus')) {
       $(this).children('.nd_edit-icon').show(); // ports
       $(this).siblings('td').find('.nd_device-details-edit').show(); // details
@@ -105,7 +104,6 @@ $(document).ready(function() {
   });
   $('.tab-content').on('mouseleave', '.nd_editable-cell', function() {
     $(this).children('.nd_hand-icon').hide();
-    $(this).children('.nd_log-icon').css('visibility', 'hidden');
     if (! $(this).is(':focus')) {
       $(this).children('.nd_edit-icon').hide(); // ports
       $(this).siblings('td').find('.nd_device-details-edit').hide(); // details
